# flake8: noqa

# import apis into api package
from ai_assistant_server_connector.api.ai_assistant_api_api import AiAssistantApiApi
from ai_assistant_server_connector.api.assistants_api import AssistantsApi
from ai_assistant_server_connector.api.assistants_server_api import AssistantsServerApi
from ai_assistant_server_connector.api.avatars_api import AvatarsApi
from ai_assistant_server_connector.api.default_api import DefaultApi
from ai_assistant_server_connector.api.goal_engagement_presets_api import GoalEngagementPresetsApi
from ai_assistant_server_connector.api.rag_api import RagApi
from ai_assistant_server_connector.api.server_api import ServerApi
from ai_assistant_server_connector.api.voices_api import VoicesApi




# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from ai_assistant_server_connector.models.response_wrapper_rag_query_response import ResponseWrapperRagQueryResponse  # noqa: E501

class TestResponseWrapperRagQueryResponse(unittest.TestCase):
    """ResponseWrapperRagQueryResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseWrapperRagQueryResponse:
        """Test ResponseWrapperRagQueryResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseWrapperRagQueryResponse`
        """
        model = ResponseWrapperRagQueryResponse()  # noqa: E501
        if include_optional:
            return ResponseWrapperRagQueryResponse(
                done = True,
                error = '',
                result = ai_assistant_server_connector.models.rag_query_response.RagQueryResponse(
                    available_free = [
                        ai_assistant_server_connector.models.search_result.SearchResult(
                            metadata = ai_assistant_server_connector.models.metadata.Metadata(), 
                            score = null, 
                            text = '', )
                        ], 
                    available_paid = [
                        ai_assistant_server_connector.models.search_result.SearchResult(
                            metadata = ai_assistant_server_connector.models.metadata.Metadata(), 
                            score = null, 
                            text = '', )
                        ], 
                    owned = [
                        
                        ], )
            )
        else:
            return ResponseWrapperRagQueryResponse(
                done = True,
        )
        """

    def testResponseWrapperRagQueryResponse(self):
        """Test ResponseWrapperRagQueryResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from ai_assistant_server_connector.models.ai_assistant_new import AiAssistantNew  # noqa: E501

class TestAiAssistantNew(unittest.TestCase):
    """AiAssistantNew unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AiAssistantNew:
        """Test AiAssistantNew
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AiAssistantNew`
        """
        model = AiAssistantNew()  # noqa: E501
        if include_optional:
            return AiAssistantNew(
                allow_text = True,
                allow_voice = True,
                approved_urls = [
                    ''
                    ],
                avatar_id = '',
                banned_keywords = [
                    ''
                    ],
                conversation_starter = '',
                conversation_style = 'formal',
                function = 'support',
                goals = [
                    ai_assistant_server_connector.models.ai_assistant_goal_create.AiAssistantGoalCreate(
                        additional_prompt = '', 
                        course_ids = [
                            56
                            ], 
                        engagement = 0.0, 
                        engagement_opt_out_duration = 0.0, 
                        engagement_preset_id = 56, 
                        is_active = True, 
                        max_engagement_count = 0.0, 
                        max_engagement_period = 0.0, 
                        max_total_engagement_count = 0.0, 
                        name = '', 
                        page_url = '', 
                        primary_course_id = 56, )
                    ],
                is_active = True,
                is_live = True,
                lexicon_items = [
                    ai_assistant_server_connector.models.ai_assistant_lexicon_item_new.AiAssistantLexiconItemNew(
                        pronounciation = '', 
                        term = '', )
                    ],
                name = '',
                prefer_voice = True,
                system_prompt_support = '',
                system_prompt_tutor = '',
                voice_id = 56
            )
        else:
            return AiAssistantNew(
                name = '',
        )
        """

    def testAiAssistantNew(self):
        """Test AiAssistantNew"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictStr
from ai_assistant_server_connector.models.response_chunk_type import ResponseChunkType
from ai_assistant_server_connector.models.usage_details import UsageDetails

class ResponseChunk(BaseModel):
    """
    ResponseChunk  # noqa: E501
    """
    text: Optional[StrictStr] = None
    type: Optional[ResponseChunkType] = None
    usage_details: Optional[UsageDetails] = None
    __properties = ["text", "type", "usage_details"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ResponseChunk:
        """Create an instance of ResponseChunk from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of usage_details
        if self.usage_details:
            _dict['usage_details'] = self.usage_details.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ResponseChunk:
        """Create an instance of ResponseChunk from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ResponseChunk.parse_obj(obj)

        _obj = ResponseChunk.parse_obj({
            "text": obj.get("text"),
            "type": obj.get("type"),
            "usage_details": UsageDetails.from_dict(obj.get("usage_details")) if obj.get("usage_details") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from ai_assistant_server_connector.models.ai_assistant_session_start import AIAssistantSessionStart  # noqa: E501

class TestAIAssistantSessionStart(unittest.TestCase):
    """AIAssistantSessionStart unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AIAssistantSessionStart:
        """Test AIAssistantSessionStart
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AIAssistantSessionStart`
        """
        model = AIAssistantSessionStart()  # noqa: E501
        if include_optional:
            return AIAssistantSessionStart(
                ai_assistant = ai_assistant_server_connector.models.ai_assistant_get.AiAssistantGet(
                    allow_text = True, 
                    allow_voice = True, 
                    approved_urls = [
                        ''
                        ], 
                    avatar_id = '', 
                    banned_keywords = [
                        ''
                        ], 
                    conversation_starter = '', 
                    conversation_style = 'formal', 
                    created_at = 56, 
                    deleted_at = 56, 
                    function = 'support', 
                    goals = [
                        ai_assistant_server_connector.models.ai_assistant_goal_get.AiAssistantGoalGet(
                            additional_prompt = '', 
                            ai_assistant_id = 56, 
                            course_ids = [
                                56
                                ], 
                            created_at = 56, 
                            engagement = 56, 
                            engagement_opt_out_duration = 56, 
                            engagement_preset = ai_assistant_server_connector.models.goal_engagement_preset_get.GoalEngagementPresetGet(
                                created_at = 56, 
                                engagement = 56, 
                                engagement_opt_out_duration = 56, 
                                id = 56, 
                                max_engagement_count = 56, 
                                max_engagement_period = 56, 
                                max_total_engagement_count = 56, 
                                name = '', 
                                order = 56, ), 
                            engagement_preset_id = 56, 
                            id = 56, 
                            interactions_summary = ai_assistant_server_connector.models.goal_interactions_summary.GoalInteractionsSummary(
                                is_available = True, 
                                last_engagement_at = 56, 
                                last_opt_out_at = 56, 
                                recent_interaction_count = 56, 
                                total_interaction_count = 56, ), 
                            is_active = True, 
                            is_fullfilled = True, 
                            last_updated_at = 56, 
                            max_engagement_count = 56, 
                            max_engagement_period = 56, 
                            max_total_engagement_count = 56, 
                            name = '', 
                            page_url = '', 
                            primary_course = ai_assistant_server_connector.models.course_public.CoursePublic(
                                description = '', 
                                id = 56, 
                                modules = [
                                    ai_assistant_server_connector.models.course_module_public.CourseModulePublic(
                                        id = 56, 
                                        lessons = [
                                            ai_assistant_server_connector.models.module_lesson_public.ModuleLessonPublic(
                                                id = 56, 
                                                title = '', )
                                            ], 
                                        public_description = '', 
                                        short_description = '', 
                                        title = '', )
                                    ], 
                                payment_type = null, 
                                title = '', 
                                url = '', ), 
                            primary_course_id = 56, )
                        ], 
                    id = 56, 
                    is_active = True, 
                    is_available = True, 
                    is_live = True, 
                    knowledgebase_state = ai_assistant_server_connector.models.knowledgebase_state.KnowledgebaseState(
                        course_data = null, ), 
                    last_updated_at = 56, 
                    lexicon_items = [
                        ai_assistant_server_connector.models.ai_assistant_lexicon_item.AiAssistantLexiconItem(
                            ai_assistant_id = 56, 
                            deleted_at = 56, 
                            id = 56, 
                            order = 56, 
                            pronounciation = '', 
                            term = '', )
                        ], 
                    name = '', 
                    prefer_voice = True, 
                    system_prompt = '', 
                    system_prompt_support = '', 
                    system_prompt_tutor = '', 
                    voice_id = 56, ),
                credentials = ai_assistant_server_connector.models.emphemeral_credentials.EmphemeralCredentials(
                    ephemeral_token = '', )
            )
        else:
            return AIAssistantSessionStart(
                ai_assistant = ai_assistant_server_connector.models.ai_assistant_get.AiAssistantGet(
                    allow_text = True, 
                    allow_voice = True, 
                    approved_urls = [
                        ''
                        ], 
                    avatar_id = '', 
                    banned_keywords = [
                        ''
                        ], 
                    conversation_starter = '', 
                    conversation_style = 'formal', 
                    created_at = 56, 
                    deleted_at = 56, 
                    function = 'support', 
                    goals = [
                        ai_assistant_server_connector.models.ai_assistant_goal_get.AiAssistantGoalGet(
                            additional_prompt = '', 
                            ai_assistant_id = 56, 
                            course_ids = [
                                56
                                ], 
                            created_at = 56, 
                            engagement = 56, 
                            engagement_opt_out_duration = 56, 
                            engagement_preset = ai_assistant_server_connector.models.goal_engagement_preset_get.GoalEngagementPresetGet(
                                created_at = 56, 
                                engagement = 56, 
                                engagement_opt_out_duration = 56, 
                                id = 56, 
                                max_engagement_count = 56, 
                                max_engagement_period = 56, 
                                max_total_engagement_count = 56, 
                                name = '', 
                                order = 56, ), 
                            engagement_preset_id = 56, 
                            id = 56, 
                            interactions_summary = ai_assistant_server_connector.models.goal_interactions_summary.GoalInteractionsSummary(
                                is_available = True, 
                                last_engagement_at = 56, 
                                last_opt_out_at = 56, 
                                recent_interaction_count = 56, 
                                total_interaction_count = 56, ), 
                            is_active = True, 
                            is_fullfilled = True, 
                            last_updated_at = 56, 
                            max_engagement_count = 56, 
                            max_engagement_period = 56, 
                            max_total_engagement_count = 56, 
                            name = '', 
                            page_url = '', 
                            primary_course = ai_assistant_server_connector.models.course_public.CoursePublic(
                                description = '', 
                                id = 56, 
                                modules = [
                                    ai_assistant_server_connector.models.course_module_public.CourseModulePublic(
                                        id = 56, 
                                        lessons = [
                                            ai_assistant_server_connector.models.module_lesson_public.ModuleLessonPublic(
                                                id = 56, 
                                                title = '', )
                                            ], 
                                        public_description = '', 
                                        short_description = '', 
                                        title = '', )
                                    ], 
                                payment_type = null, 
                                title = '', 
                                url = '', ), 
                            primary_course_id = 56, )
                        ], 
                    id = 56, 
                    is_active = True, 
                    is_available = True, 
                    is_live = True, 
                    knowledgebase_state = ai_assistant_server_connector.models.knowledgebase_state.KnowledgebaseState(
                        course_data = null, ), 
                    last_updated_at = 56, 
                    lexicon_items = [
                        ai_assistant_server_connector.models.ai_assistant_lexicon_item.AiAssistantLexiconItem(
                            ai_assistant_id = 56, 
                            deleted_at = 56, 
                            id = 56, 
                            order = 56, 
                            pronounciation = '', 
                            term = '', )
                        ], 
                    name = '', 
                    prefer_voice = True, 
                    system_prompt = '', 
                    system_prompt_support = '', 
                    system_prompt_tutor = '', 
                    voice_id = 56, ),
                credentials = ai_assistant_server_connector.models.emphemeral_credentials.EmphemeralCredentials(
                    ephemeral_token = '', ),
        )
        """

    def testAIAssistantSessionStart(self):
        """Test AIAssistantSessionStart"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
